@@ -350,6 +350,90 @@ def modify_file(remote_full_path, req_url, modified_file_name, recovery_full_pat
     return code, err
 
 
+def move_file(original_full_path, req_url, new_full_path, timeout=3, logger=logging):
+    """
+    移动文件
+    :param original_full_path: 远程文件存储路径及完整文件名称，全地址
+    :param req_url: 请求URL地址，必传
+    :param new_full_path: 移动后的文件存储路径（存在直接移动，不存在则创建），不包含文件名（移动后文件名称与原文件名一致）
+    :param timeout: 超时时间
+    :param logger: 日志对象
+    :return:
+    """
+    code, err = None, None
+    try:
+        logger = logger if logger else logging
+        if not original_full_path or not req_url or not new_full_path:
+            code = 128502
+            return code, code_dict.get(str(code))
+        param = {'original_file_path': original_full_path, 'new_file_path': new_full_path}
+        resp = requests.post(url=req_url, json=param, verify=False, timeout=timeout)
+        http_code = resp.status_code
+        if http_code == 200:
+            response = resp.content.decode('utf-8')
+            try:
+                body = json.loads(response)
+            except Exception as exc:
+                body = response
+            code = body.get('code')
+            err = body.get('err', '') if body.get('err', '') else code_dict.get(str(code))
+        else:
+            code = 1
+            err = "请求失败"
+    except requests.ConnectTimeout:
+        code, err = 128512, code_dict.get("128512")
+    except requests.exceptions.ConnectionError:
+        code, err = 128512, code_dict.get("128512")
+    except requests.exceptions.ReadTimeout:
+        code, err = 128509, code_dict.get("128509")
+    except Exception as exc:
+        logger.error(traceback.format_exc())
+        raise_(Exception, exc)
+    return code, err
+
+
+def copy_file(original_full_path, req_url, new_full_path, timeout=3, logger=logging):
+    """
+    复制文件
+    :param original_full_path: 远程文件存储路径及完整文件名称，全地址
+    :param req_url: 请求URL地址，必传
+    :param new_full_path: 复制后的文件路径（传文件名则变更文件名称，不传则为原文件名称）；路径存在直接移动，不存在则创建
+    :param timeout: 超时时间
+    :param logger: 日志对象
+    :return:
+    """
+    code, err = None, None
+    try:
+        logger = logger if logger else logging
+        if not original_full_path or not req_url or not new_full_path:
+            code = 128502
+            return code, code_dict.get(str(code))
+        param = {'original_file_path': original_full_path, 'new_file_path': new_full_path}
+        resp = requests.post(url=req_url, json=param, verify=False, timeout=timeout)
+        http_code = resp.status_code
+        if http_code == 200:
+            response = resp.content.decode('utf-8')
+            try:
+                body = json.loads(response)
+            except Exception as exc:
+                body = response
+            code = body.get('code')
+            err = body.get('err', '') if body.get('err', '') else code_dict.get(str(code))
+        else:
+            code = 1
+            err = "请求失败"
+    except requests.ConnectTimeout:
+        code, err = 128512, code_dict.get("128512")
+    except requests.exceptions.ConnectionError:
+        code, err = 128512, code_dict.get("128512")
+    except requests.exceptions.ReadTimeout:
+        code, err = 128509, code_dict.get("128509")
+    except Exception as exc:
+        logger.error(traceback.format_exc())
+        raise_(Exception, exc)
+    return code, err
+
+
 def gen_file(file_path, size=1024):
     """
     将文件读取为文件流
